#ifndef NT2_INCLUDE_FUNCTIONS_MOD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MOD_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/mod.hpp>

#endif
